@@ -29,7 +29,9 @@ import numpy as np
 import laygo2.object.template
 import laygo2.object.physical
 import laygo2.object.database
-import laygo2_tech as tech
+#Should be `import laygo2_tech as tech` for actual use.
+import laygo2.examples.laygo2_tech as tech
+#import laygo2_tech as tech
 
 
 tech_params = tech.tech_params
